==> zio-aws-ecs_2.13-5.17.122.1-sources.jar: zio/aws/ecs/model/PutAccountSettingDefaultResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PutAccountSettingDefaultResponse(
    setting: Option[zio.aws.ecs.model.Setting] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse = {
    import PutAccountSettingDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
      .builder()
      .optionallyWith(setting.map(value => value.buildAwsValue()))(_.setting)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.PutAccountSettingDefaultResponse.ReadOnly =
    zio.aws.ecs.model.PutAccountSettingDefaultResponse.wrap(buildAwsValue())
}
object PutAccountSettingDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.PutAccountSettingDefaultResponse =
      zio.aws.ecs.model.PutAccountSettingDefaultResponse(
        setting.map(value => value.asEditable)
      )
    def setting: Option[zio.aws.ecs.model.Setting.ReadOnly]
    def getSetting: ZIO[Any, AwsError, zio.aws.ecs.model.Setting.ReadOnly] =
      AwsError.unwrapOptionField("setting", setting)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
  ) extends zio.aws.ecs.model.PutAccountSettingDefaultResponse.ReadOnly {
    override val setting: Option[zio.aws.ecs.model.Setting.ReadOnly] = scala
      .Option(impl.setting())
      .map(value => zio.aws.ecs.model.Setting.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
  ): zio.aws.ecs.model.PutAccountSettingDefaultResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ecs_2.13-5.19.7.3-sources.jar: zio/aws/ecs/model/PutAccountSettingDefaultResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutAccountSettingDefaultResponse(
    setting: Optional[zio.aws.ecs.model.Setting] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse = {
    import PutAccountSettingDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
      .builder()
      .optionallyWith(setting.map(value => value.buildAwsValue()))(_.setting)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.PutAccountSettingDefaultResponse.ReadOnly =
    zio.aws.ecs.model.PutAccountSettingDefaultResponse.wrap(buildAwsValue())
}
object PutAccountSettingDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.PutAccountSettingDefaultResponse =
      zio.aws.ecs.model.PutAccountSettingDefaultResponse(
        setting.map(value => value.asEditable)
      )
    def setting: Optional[zio.aws.ecs.model.Setting.ReadOnly]
    def getSetting: ZIO[Any, AwsError, zio.aws.ecs.model.Setting.ReadOnly] =
      AwsError.unwrapOptionField("setting", setting)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
  ) extends zio.aws.ecs.model.PutAccountSettingDefaultResponse.ReadOnly {
    override val setting: Optional[zio.aws.ecs.model.Setting.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.setting())
        .map(value => zio.aws.ecs.model.Setting.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.PutAccountSettingDefaultResponse
  ): zio.aws.ecs.model.PutAccountSettingDefaultResponse.ReadOnly = new Wrapper(
    impl
  )
}
